#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-DU0blLEVAaZElXdaZlCbTb
key:                  haskell-language-server-2.3.0.0-DU0blLEVAaZElXdaZlCbTb
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  53b8cf28946451d8bd170df181516aa0
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-DU0blLEVAaZElXdaZlCbTb
depends:
    aeson-pretty-0.8.10-Dq46Vb0SwSV2AiUtN6wUKh
    async-2.2.6-Gml4H6UctygFSqCTsp1iZf base-4.18.2.1
    base16-bytestring-1.0.2.0-31yUxkNIVeJ6WQ1ftMFCcb
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-Dr7tkgtlkwAD12N9xZyl0y
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-COAoMleqge7G93j2zK3Os3 filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-roa2yceaWZInAuFLFv0WZ
    githash-0.1.6.3-3EPyTzg4LKQI7CrdYLMav3
    hie-bios-0.12.0-CzSj97JZ1lrGvDDIJRQtzn
    hiedb-0.4.3.0-Fwuou394YkhHgRNX5gRWe7
    hls-alternate-number-format-plugin-2.3.0.0-2PUxNiSchuOGbyUyQBCdUm
    hls-cabal-fmt-plugin-2.3.0.0-J562JvKTd22DOPpRV2uKQ0
    hls-cabal-plugin-2.3.0.0-BgxVHqjgWHaDutGN3B6WLE
    hls-call-hierarchy-plugin-2.3.0.0-3TnjPUYFuEkALyVSwxXkGg
    hls-change-type-signature-plugin-2.3.0.0-IiLA80FoeewA14fqmWgJnK
    hls-class-plugin-2.3.0.0-7IqFb7f4464zZWTnbY8UA
    hls-code-range-plugin-2.3.0.0-2NGsEh3NUeFEBm7xwdHKrl
    hls-eval-plugin-2.3.0.0-GHFSic56p7mGFexGhbrY5I
    hls-explicit-fixity-plugin-2.3.0.0-3JurYXNSH8jBz0FE56RIdl
    hls-explicit-imports-plugin-2.3.0.0-295QexLCZxX4EZuG5iSlcz
    hls-explicit-record-fields-plugin-2.3.0.0-30mi1YSoAshGM6SCwqvTyJ
    hls-fourmolu-plugin-2.3.0.0-EkvpFGhDdocK9mn7Nc4YCz
    hls-gadt-plugin-2.3.0.0-IMXz2wy5X6oHYevm1Sr9SM
    hls-graph-2.3.0.0-1z80l9DPzvC9twCkDucgLx
    hls-hlint-plugin-2.3.0.0-8fjV4KUpejZ2O8sQr0o4kP
    hls-module-name-plugin-2.3.0.0-IgkKipDY9bR6YHGdDtlA2b
    hls-ormolu-plugin-2.3.0.0-7u8NgxuHbqo5CvHhi1DQt5
    hls-overloaded-record-dot-plugin-2.3.0.0-AF8RfvLvv1uL3ZUHIUm5s
    hls-plugin-api-2.3.0.0-CCML0HyRmic6Eq7DkGPRu6
    hls-pragmas-plugin-2.3.0.0-8JV4nuloJx7KCymTtwJ1cI
    hls-qualify-imported-names-plugin-2.3.0.0-AfMPTrbUjeyCINQp5977sD
    hls-refactor-plugin-2.3.0.0-CzQ9vbQyN2xH8nN801U6Sp
    hls-rename-plugin-2.3.0.0-91e1NJvBfLQ1HOQ78TasxD
    hls-retrie-plugin-2.3.0.0-H5HKJpqxJwX9khzNqjT48
    hls-splice-plugin-2.3.0.0-DiSiX01thIY5oWMm9E9xon
    hls-stylish-haskell-plugin-2.3.0.0-L6rlAGOjA9tBZ1igrtf8XC
    lsp-2.2.0.0-1GTZZafkEuOHztrSNMPAEV
    optparse-applicative-0.18.1.0-3oCCN3996F8HtRiEC4P5yD
    optparse-simple-0.1.1.4-HmUE8waKLyI2QKkJ2rSo6Y
    prettyprinter-1.7.1-890hJtP71KxJCLiD1l5JnX process-1.6.19.0
    safe-exceptions-0.1.7.4-BGySaU8uJj39VCxO5h0Lp3
    sqlite-simple-0.4.19.0-4lfN9MLoGcgKpl6bJV4Tf8 text-2.0.2
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

